@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2014 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2015 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -81,13 +81,13 @@ to select people from system groups.
 
 =head2 replace_relations - user identifier
 
-When you delete user there are could be minor links to him in RT DB.
-This option allow you to replace this links with link to other user.
-This links are Creator and LastUpdatedBy, but NOT any watcher roles,
-this means that if user is watcher(Requestor, Owner,
-Cc or AdminCc) of the ticket or queue then link would be deleted.
+When you delete a user there could be minor links to them in the RT database.
+This option allow you to replace these links with links to the new user.
+The replaceable links are Creator and LastUpdatedBy, but NOT any watcher roles.
+This means that if the user is a watcher(Requestor, Owner,
+Cc or AdminCc) of the ticket or queue then the link would be deleted.
 
-This argument could be user id or name.
+This argument could be a user id or name.
 
 =head2 no_tickets - boolean
 
