@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2014 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2015 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -830,7 +830,7 @@ sub create_ticket {
         $args{'MIMEObj'} = MIME::Entity->build(
             From    => Encode::encode( "UTF-8", $args{'Requestor'} ),
             Subject => RT::Interface::Email::EncodeToMIME( String => $args{'Subject'} ),
-            Type    => "text/plain",
+            Type    => $args{ContentType} // "text/plain",
             Charset => "UTF-8",
             Data    => Encode::encode( "UTF-8", $content ),
         );
